@@ -542,7 +542,7 @@ goodtags1
      "title", "track" ,"frame", "param", "base", "area", "font", "code", "span", "main",
      "abbr", "body", "link", "menu", "math", "meta", "samp", "cite",
      "head", "html", "poem", "form", "cite", "ref", "div", "pre", "sub", "nav",
-     "sup", "big", "del", "map", "bdo", "var", "dfn", "kbd", "col",
+     "sup", "big", "del", "map", "bdo", "var", "dfn", "kbd", "col", "wbr",
      "ins", "bdi", "dir", "img", "h1", "h2", "h3", "h4", "h5", "h6",
      "li", "ul", "ol", "tt", "dd", "dl", "dt", "hr", "em", "b", "i",
      "s", "u", "p", "q", "a"]
@@ -597,6 +597,7 @@ chartransforlink '$' = "\\${}"
 chartransforlink '\\' = "\\textbackslash{}"
 chartransforlink '<' = "<{}"
 chartransforlink '>' = ">{}"
+chartransforlink '^' = "\\%5E"
 chartransforlink c
   | 127 < ord c =
     concat (map chartransforlink $ escapeURIString (const False) [c])
